@@ -36,5 +36,5 @@ func TestAny(t *testing.T) {
 func TestSet(t *testing.T) {
 	ctx := testctx.New()
 	skips.Set(ctx, skips.Publish, skips.Announce)
-	require.Equal(t, []string{"publish", "announce"}, maps.Keys(ctx.Skips))
+	require.ElementsMatch(t, []string{"publish", "announce"}, maps.Keys(ctx.Skips))
 }
